"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.connectToDatabase = exports.addNewConnectionConfiguration = exports.deleteConnectionConfiguration = void 0;
const vscode = require("vscode");
const simple_client_1 = require("./simple-client");
const extension_1 = require("./extension");
const deleteConnectionConfiguration = (context, connectionsSidepanel) => async (item) => {
    const without = context.globalState
        .get(extension_1.storageKey, [])
        .filter(({ name }) => name !== item.config.name);
    context.globalState.update(extension_1.storageKey, without);
    await context.secrets.delete(item.config.name);
    connectionsSidepanel.refresh();
    vscode.window.showInformationMessage(`Successfully deleted connection configuration "${item.config.name}"`);
    connectionsSidepanel.refresh();
};
exports.deleteConnectionConfiguration = deleteConnectionConfiguration;
const addNewConnectionConfiguration = (context, connectionsSidepanel) => async () => {
    const displayName = await getUserInput("Database Display Name ", true);
    if (!displayName) {
        vscode.window.showErrorMessage(`A valid display name is required.`);
        return;
    }
    const endpointURL = await getUserInput("Endpoint URL", true);
    if (!endpointURL) {
        vscode.window.showErrorMessage(`A valid endpoint URL is required.`);
        return;
    }
    const user = await getUserInput("User", false);
    const password = await getUserInput("Password", false, {
        password: true,
    });
    const passwordKey = `sparql-notebook.${displayName}`;
    await context.secrets.store(passwordKey, password || "");
    const config = {
        name: displayName,
        endpointURL: endpointURL || "",
        user: user ?? "",
        passwordKey,
    };
    const existing = context.globalState
        .get(extension_1.storageKey, [])
        .filter(({ name }) => name !== displayName);
    existing.push(config);
    context.globalState.update(extension_1.storageKey, existing);
    connectionsSidepanel.refresh();
};
exports.addNewConnectionConfiguration = addNewConnectionConfiguration;
const connectToDatabase = (context, connectionsSidepanel) => async (item) => {
    let selectedName;
    if (!item) {
        const names = context.globalState
            .get(extension_1.storageKey, [])
            .map(({ name }) => name);
        const namePicked = await vscode.window.showQuickPick(names, {
            ignoreFocusOut: true,
        });
        if (!namePicked) {
            vscode.window.showErrorMessage(`Invalid database connection name.`);
            return;
        }
        selectedName = namePicked;
    }
    else {
        selectedName = item.config.name;
    }
    const match = context.globalState
        .get(extension_1.storageKey, [])
        .find(({ name }) => name === selectedName);
    if (!match) {
        vscode.window.showErrorMessage(`"${selectedName}" not found. Please add the connection config in the sidebar before connecting.`);
        return;
    }
    const password = await context.secrets.get(match.passwordKey);
    if (password === undefined) {
        vscode.window.showErrorMessage(`Connection password not found in secret store.`);
        return;
    }
    extension_1.globalConnection.connection = {
        data: {
            name: match.name,
            endpointURL: match.endpointURL,
            user: match.user,
            passwordKey: password,
        },
    };
    try {
        const c = extension_1.globalConnection.connection.data;
        const client = new simple_client_1.SparqlClient(c.endpointURL, c.user, c.passwordKey);
        const result = await client.query("SELECT * WHERE {?s ?p ?o.} LIMIT 1");
        connectionsSidepanel.setActive(match.name);
        vscode.window.showInformationMessage(`Successfully connected to "${match.name}"`);
    }
    catch (err) {
        console.log(err);
        vscode.window.showErrorMessage(
        // @ts-ignore
        `Failed to connect to "${match.name}": ${err.message}`);
        extension_1.globalConnection.connection = null;
        connectionsSidepanel.setActive(null);
    }
};
exports.connectToDatabase = connectToDatabase;
const getUserInput = async (name, required, options) => {
    const value = await vscode.window.showInputBox({
        title: name,
        validateInput: required ? requiredValidator(name) : undefined,
        ignoreFocusOut: true,
        ...options,
    });
    return value;
};
const requiredValidator = (name) => (value) => {
    if (!value) {
        return `${name} is required`;
    }
    return undefined;
};
//# sourceMappingURL=commands.js.map