"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SparqlNotebookController = void 0;
const vscode = require("vscode");
const extension_1 = require("./extension");
const simple_client_1 = require("./simple-client");
class SparqlNotebookController {
    constructor() {
        this.controllerId = "sparql-notebook-controller-id";
        this.notebookType = "sparql-notebook";
        this.label = "Sparql Notebook";
        this.supportedLanguages = ["sparql", "rdfmapping"];
        this._executionOrder = 0;
        this._controller = vscode.notebooks.createNotebookController(this.controllerId, this.notebookType, this.label);
        this._controller.supportedLanguages = this.supportedLanguages;
        this._controller.supportsExecutionOrder = true;
        this._controller.executeHandler = this._execute.bind(this);
    }
    _execute(cells, _notebook, _controller) {
        for (let cell of cells) {
            this._doExecution(cell);
        }
    }
    async _doExecution(cell) {
        const execution = this._controller.createNotebookCellExecution(cell);
        execution.executionOrder = ++this._executionOrder;
        execution.start(Date.now()); // Keep track of elapsed time to execute cell.
        if (extension_1.globalConnection.connection === null) {
            vscode.window.showErrorMessage("Not connected to a SPARQL Endpoint");
            execution.end(true, Date.now());
            return;
        }
        const client = new simple_client_1.SparqlClient(extension_1.globalConnection.connection.data.endpointURL, extension_1.globalConnection.connection.data.user, extension_1.globalConnection.connection.data.passwordKey);
        const queryResult = await client
            .query(cell.document.getText())
            .catch((error) => {
            execution.replaceOutput([
                new vscode.NotebookCellOutput([
                    vscode.NotebookCellOutputItem.error(error),
                ]),
            ]);
            execution.end(true, Date.now());
            return;
        });
        // content type
        const contentType = queryResult.headers["content-type"];
        const data = queryResult.data;
        if (contentType === "application/sparql-results+json") {
            // sparql ask or select
            execution.replaceOutput([this._writeSparqlJsonResult(data)]);
        }
        else if (contentType === "text/turtle") {
            // sparql construct
            execution.replaceOutput([this._writeTurtleResult(data)]);
        }
        else if (contentType === "application/json") {
            // stardog is returning and error as json
            execution.replaceOutput([this._writeError(data)]);
        }
        execution.end(true, Date.now());
    }
    _writeTurtleResult(resultTTL) {
        return new vscode.NotebookCellOutput([
            // vscode.NotebookCellOutputItem.text(resultTTL, "application/x-turtle"),
            vscode.NotebookCellOutputItem.text(resultTTL, "text/x-turtle"),
            vscode.NotebookCellOutputItem.text(resultTTL, "text/plain"),
        ]);
    }
    _writeSparqlJsonResult(resultJson) {
        if (resultJson.hasOwnProperty("boolean")) {
            // ASK Query result
            return new vscode.NotebookCellOutput([this._writeHtml(resultJson)]);
        }
        return new vscode.NotebookCellOutput([
            this._writeHtml(resultJson),
            this._writeJson(JSON.stringify(resultJson, null, "   ")),
        ]);
    }
    _writeHtml(resultJson) {
        let resultHtml = `
    <style>
  
*, *:before, *:after {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
}

table {
  background-color: rgb(46, 53, 62);
  border-radius: 0.25em;
  border-collapse: collapse;
  margin: 1em;
}
th {
  border-bottom: 1px solid #364043;
  color: #28b1de;
  font-size: 0.85em;
  font-weight: 600;
  padding: 0.5em 1em;
  text-align: left;
}
td {
  color: lightgrey;
  font-weight: 400;
  padding: 0.65em 1em;
  text-align: left;
}
tr > td:last-of-type {
  text-align: right;
}
tbody tr {
  transition: background 0.25s ease;
}
tbody tr:hover {
  background: #014055;
}


    </style>
    <table>
    <tr>`;
        resultJson.head.vars.forEach((heading) => {
            resultHtml += `\n        <th>${heading}</th>\n`;
        });
        resultJson.results.bindings.forEach((result) => {
            resultHtml += "    <tr>";
            resultJson.head.vars.forEach((heading) => {
                resultHtml += `\n        <td>${result[heading]?.value
                    ?.replaceAll("<", "&lt;")
                    ?.replaceAll(">", "&gt;") ?? ""}</td>\n`;
            });
            resultHtml += "    </tr>\n";
        });
        resultHtml += "</table>";
        return vscode.NotebookCellOutputItem.text(resultHtml, "text/html");
    }
    _writeJson(jsonResult) {
        return vscode.NotebookCellOutputItem.text(jsonResult, "text/x-json");
    }
    _writeError(error) {
        return new vscode.NotebookCellOutput([
            vscode.NotebookCellOutputItem.error({
                name: "SPARQL error",
                message: error.message,
            }),
        ]);
    }
    dispose() { }
}
exports.SparqlNotebookController = SparqlNotebookController;
//# sourceMappingURL=sparql-notebook-controller.js.map